@@ -6,7 +6,6 @@
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
 #undef HAVE_LIBBZ2
-#undef HAVE_LIBFAM
 #undef HAVE_LIBJPEG
 #undef HAVE_MEDUSA
 #undef HAVE_STPCPY
@@ -21,3 +20,7 @@
 #undef bzopen
 #undef bzread
 #undef bzwrite
+#define HAVE_GTK_MULTIHEAD /* needed for egg-screen-exec functions */
+#undef HAVE_STARTUP_NOTIFICATION
+#undef HAVE_EXIF
+#undef HAVE_OLD_EXIF
