@@ -41,13 +41,8 @@
 #include "nautilus-search-bar.h"
 #include "nautilus-window-manage-views.h"
 #include "nautilus-zoom-control.h"
-#include <eel/eel-accessibility.h>
-#include <eel/eel-debug.h>
-#include <eel/eel-gdk-extensions.h>
-#include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
-#include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkx.h>
@@ -61,13 +56,15 @@
 #include <gtk/gtktreemodel.h>
 #include <gtk/gtkliststore.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-macros.h>
+#ifdef HAVE_X11_XF86KEYSYM_H
+#include <X11/XF86keysym.h>
+#endif
 #include <libgnomeui/gnome-uidefs.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-horizontal-splitter.h>
-#include <libnautilus-private/nautilus-icon-factory.h>
+#include <libnautilus-private/nautilus-icon-info.h>
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-mime-actions.h>
 #include <libnautilus-private/nautilus-program-choosing.h>
@@ -117,9 +114,10 @@ static void navigation_bar_location_changed_callback (GtkWidget                *
 static void navigation_bar_cancel_callback           (GtkWidget                *widget,
 						      NautilusNavigationWindow *window);
 static void path_bar_location_changed_callback       (GtkWidget                *widget,
-						      const char               *uri,
+						      GFile                    *path,
 						      NautilusNavigationWindow *window);
 static void always_use_location_entry_changed        (gpointer                  callback_data);
+static void always_use_browser_changed               (gpointer                  callback_data);
 
 static void nautilus_navigation_window_set_bar_mode  (NautilusNavigationWindow *window, 
 						      NautilusBarMode           mode);
@@ -130,8 +128,21 @@ static void search_bar_cancel_callback               (GtkWidget                *
 
 static void nautilus_navigation_window_show_location_bar_temporarily (NautilusNavigationWindow *window);
 
-GNOME_CLASS_BOILERPLATE (NautilusNavigationWindow, nautilus_navigation_window,
-			 NautilusWindow, NAUTILUS_TYPE_WINDOW)
+static void view_as_menu_switch_views_callback	     (GtkComboBox              *combo_box,
+						      NautilusWindow           *window);
+
+G_DEFINE_TYPE (NautilusNavigationWindow, nautilus_navigation_window, NAUTILUS_TYPE_WINDOW)
+#define parent_class nautilus_navigation_window_parent_class
+
+static const struct {
+	unsigned int keyval;
+	const char *action;
+} extra_navigation_window_keybindings [] = {
+#ifdef HAVE_X11_XF86KEYSYM_H
+	{ XF86XK_Back,		NAUTILUS_ACTION_BACK },
+	{ XF86XK_Forward,	NAUTILUS_ACTION_FORWARD }
+#endif
+};
 
 static void
 location_button_toggled_cb (GtkToggleButton *toggle,
@@ -164,11 +175,12 @@ location_button_create (NautilusNavigationWindow *window)
 
 	button = g_object_new (GTK_TYPE_TOGGLE_BUTTON,
 			       "image", image,
+			       "focus-on-click", FALSE,
 			       "active", location_button_should_be_active (window),
 			       NULL);
 
-	gtk_tooltips_set_tip (window->details->tooltips, button,
-			      _("Toggle between button and text-based location bar"), NULL);
+	gtk_widget_set_tooltip_text (button,
+				     _("Toggle between button and text-based location bar"));
 
 	g_signal_connect (button, "toggled",
 			  G_CALLBACK (location_button_toggled_cb), window);
@@ -176,7 +188,7 @@ location_button_create (NautilusNavigationWindow *window)
 }
 
 static void
-nautilus_navigation_window_instance_init (NautilusNavigationWindow *window)
+nautilus_navigation_window_init (NautilusNavigationWindow *window)
 {
 	GtkUIManager *ui_manager;
 	GtkWidget *toolbar;
@@ -184,12 +196,8 @@ nautilus_navigation_window_instance_init (NautilusNavigationWindow *window)
 	GtkWidget *view_as_menu_vbox;
 	GtkToolItem *item;
 	GtkWidget *hbox, *vbox, *eventbox, *extras_vbox;
-	
-	window->details = g_new0 (NautilusNavigationWindowDetails, 1);
 
-	window->details->tooltips = gtk_tooltips_new ();
-	g_object_ref (window->details->tooltips);
-	gtk_object_sink (GTK_OBJECT (window->details->tooltips));
+	window->details = G_TYPE_INSTANCE_GET_PRIVATE (window, NAUTILUS_TYPE_NAVIGATION_WINDOW, NautilusNavigationWindowDetails);
 
 	window->details->content_paned = nautilus_horizontal_splitter_new ();
 	gtk_table_attach (GTK_TABLE (NAUTILUS_WINDOW (window)->details->table),
@@ -304,8 +312,11 @@ nautilus_navigation_window_instance_init (NautilusNavigationWindow *window)
 			    item, -1);
 	
 	window->view_as_combo_box = gtk_combo_box_new_text ();
+	gtk_combo_box_set_focus_on_click (GTK_COMBO_BOX (window->view_as_combo_box), FALSE);
 	gtk_box_pack_end (GTK_BOX (view_as_menu_vbox), window->view_as_combo_box, TRUE, FALSE, 0);
 	gtk_widget_show (window->view_as_combo_box);
+	g_signal_connect_object (window->view_as_combo_box, "changed",
+				 G_CALLBACK (view_as_menu_switch_views_callback), window, 0);
 
 	/* Allocate the zoom control and place on the right next to the menu.
 	 * It gets shown later, if the view-frame contains something zoomable.
@@ -343,6 +354,10 @@ nautilus_navigation_window_instance_init (NautilusNavigationWindow *window)
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_ALWAYS_USE_LOCATION_ENTRY,
 						  always_use_location_entry_changed,
 						  window, G_OBJECT (window));
+
+	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER,
+						  always_use_browser_changed,
+						  window, G_OBJECT (window));
 }
 
 static void
@@ -370,26 +385,36 @@ always_use_location_entry_changed (gpointer callback_data)
 					   window);
 }
 
+static void
+always_use_browser_changed (gpointer callback_data)
+{
+	NautilusNavigationWindow *window;
+
+	window = NAUTILUS_NAVIGATION_WINDOW (callback_data);
+
+	nautilus_navigation_window_update_spatial_menu_item (window);
+}
+
 static int
 bookmark_list_get_uri_index (GList *list,
-			     const char *uri)
+			     GFile *location)
 {
 	NautilusBookmark *bookmark;
 	GList *l;
-	char *tmp;
+	GFile *tmp;
 	int i;
 
-	g_return_val_if_fail (uri != NULL, -1);
+	g_return_val_if_fail (location != NULL, -1);
 
 	for (i = 0, l = list; l != NULL; i++, l = l->next) {
 		bookmark = NAUTILUS_BOOKMARK (l->data);
 
-		tmp = nautilus_bookmark_get_uri (bookmark);
-		if (strcmp (tmp, uri) == 0) {
-			g_free (tmp);
+		tmp = nautilus_bookmark_get_location (bookmark);
+		if (g_file_equal (location, tmp)) {
+			g_object_unref (tmp);
 			return i;
 		}
-		g_free (tmp);
+		g_object_unref (tmp);
 	}
 
 	return -1;
@@ -397,7 +422,7 @@ bookmark_list_get_uri_index (GList *list,
 
 static void
 path_bar_location_changed_callback (GtkWidget *widget,
-				    const char *uri,
+				    GFile *location,
 				    NautilusNavigationWindow *window)
 {
 	int i;
@@ -405,11 +430,11 @@ path_bar_location_changed_callback (GtkWidget *widget,
 	g_assert (NAUTILUS_IS_NAVIGATION_WINDOW (window));
 
 	/* check whether we already visited the target location */
-	i = bookmark_list_get_uri_index (window->back_list, uri);
+	i = bookmark_list_get_uri_index (window->back_list, location);
 	if (i >= 0) {
 		nautilus_navigation_window_back_or_forward (window, TRUE, i);
 	} else {
-		nautilus_window_go_to (NAUTILUS_WINDOW (window), uri);
+		nautilus_window_go_to (NAUTILUS_WINDOW (window), location);
 	}
 }
 
@@ -449,8 +474,12 @@ navigation_bar_location_changed_callback (GtkWidget *widget,
 					  const char *uri,
 					  NautilusNavigationWindow *window)
 {
+	GFile *location;
+	
 	hide_temporary_bars (window);
-	nautilus_window_go_to (NAUTILUS_WINDOW (window), uri);
+	location = g_file_new_for_uri (uri);
+	nautilus_window_go_to (NAUTILUS_WINDOW (window), location);
+	g_object_unref (location);
 }
 
 static void
@@ -631,6 +660,36 @@ nautilus_navigation_window_state_event (GtkWidget *widget,
 	return FALSE;
 }
 
+static gboolean
+nautilus_navigation_window_key_press_event (GtkWidget *widget,
+					    GdkEventKey *event)
+{
+	NautilusNavigationWindow *window;
+	int i;
+
+	window = NAUTILUS_NAVIGATION_WINDOW (widget);
+
+	for (i = 0; i < G_N_ELEMENTS (extra_navigation_window_keybindings); i++) {
+		if (extra_navigation_window_keybindings[i].keyval == event->keyval) {
+			GtkAction *action;
+
+			action = gtk_action_group_get_action (window->details->navigation_action_group,
+							      extra_navigation_window_keybindings[i].action);
+			g_assert (action != NULL);
+
+			g_assert (action != NULL);
+			if (gtk_action_is_sensitive (action)) {
+				gtk_action_activate (action);
+				return TRUE;
+			}
+
+			break;
+		}
+	}
+
+	return GTK_WIDGET_CLASS (nautilus_navigation_window_parent_class)->key_press_event (widget, event);
+}
+
 static void
 nautilus_navigation_window_destroy (GtkObject *object)
 {
@@ -640,6 +699,7 @@ nautilus_navigation_window_destroy (GtkObject *object)
 
 	window->sidebar = NULL;
 	g_list_foreach (window->sidebar_panels, (GFunc)g_object_unref, NULL);
+	g_list_free (window->sidebar_panels);
 	window->sidebar_panels = NULL;
 
 	window->view_as_combo_box = NULL;
@@ -649,11 +709,6 @@ nautilus_navigation_window_destroy (GtkObject *object)
 
 	window->details->content_paned = NULL;
 
-	if (window->details->tooltips) {
-		g_object_unref (window->details->tooltips);
-		window->details->tooltips = NULL;
-	}
-	
 	GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
 
@@ -668,8 +723,6 @@ nautilus_navigation_window_finalize (GObject *object)
 	nautilus_navigation_window_clear_back_list (window);
 	nautilus_navigation_window_clear_forward_list (window);
 
- 	g_free (window->details);
-
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -712,10 +765,8 @@ nautilus_navigation_window_add_sidebar_panel (NautilusNavigationWindow *window,
 	g_signal_connect (sidebar_panel, "tab_icon_changed",
 			  (GCallback)side_panel_image_changed_callback, window);
 
-	
-	g_object_ref (sidebar_panel);
-	window->sidebar_panels = g_list_prepend (window->sidebar_panels, sidebar_panel);
-
+	window->sidebar_panels = g_list_prepend (window->sidebar_panels,
+						 g_object_ref (sidebar_panel));
 
 	/* Show if default */
 	sidebar_id = nautilus_sidebar_get_sidebar_id (sidebar_panel);
@@ -807,8 +858,10 @@ view_as_menu_switch_views_callback (GtkComboBox *combo_box, NautilusWindow *wind
 	g_assert (NAUTILUS_IS_WINDOW (window));
 
 	active = gtk_combo_box_get_active (combo_box);
-	
-	if (active < GPOINTER_TO_INT (g_object_get_data (G_OBJECT (combo_box), "num viewers"))  ) {
+
+	if (active < 0) {
+		return;
+	} else if (active < GPOINTER_TO_INT (g_object_get_data (G_OBJECT (combo_box), "num viewers"))) {
 		activate_nth_short_list_item (window, active);
 	} else {
 		activate_extra_viewer (window);
@@ -841,7 +894,7 @@ load_view_as_menu (NautilusWindow *window)
              node != NULL; 
              node = node->next, ++index) {
 		info = nautilus_view_factory_lookup (node->data);
-		gtk_combo_box_append_text (combo_box, _(info->view_as_label));
+		gtk_combo_box_append_text (combo_box, _(info->view_combo_label));
 
 		if (nautilus_window_content_view_matches_iid (NAUTILUS_WINDOW (window), (char *)node->data)) {
 			selected_index = index;
@@ -855,13 +908,10 @@ load_view_as_menu (NautilusWindow *window)
 		id = nautilus_window_get_content_view_id (window);
 		info = nautilus_view_factory_lookup (id);
 		gtk_combo_box_append_text (GTK_COMBO_BOX (NAUTILUS_NAVIGATION_WINDOW (window)->view_as_combo_box),
-					   _(info->view_as_label));
+					   _(info->view_combo_label));
 		selected_index = index;
 	}
 
-	g_signal_connect (GTK_COMBO_BOX (NAUTILUS_NAVIGATION_WINDOW (window)->view_as_combo_box), 
-			  "changed", G_CALLBACK (view_as_menu_switch_views_callback), window);
-
 	gtk_combo_box_set_active (GTK_COMBO_BOX (NAUTILUS_NAVIGATION_WINDOW (window)->view_as_combo_box), selected_index);
 }
 
@@ -896,10 +946,10 @@ real_set_title (NautilusWindow *window, const char *title)
 	return changed;
 }
 
-static char *
-real_get_icon_name (NautilusWindow *window)
+static NautilusIconInfo *
+real_get_icon (NautilusWindow *window)
 {
-	return g_strdup ("file-manager");
+	return nautilus_icon_info_lookup_from_name ("file-manager", 48);
 }
 
 static void
@@ -1025,9 +1075,13 @@ search_bar_activate_callback (NautilusSearchBar *bar,
 	NautilusDirectory *directory;
 	NautilusSearchDirectory *search_directory;
 	NautilusQuery *query;
+	GFile *location;
 
 	uri = nautilus_search_directory_generate_new_uri ();
-	directory = nautilus_directory_get (uri);
+	location = g_file_new_for_uri (uri);
+	g_free (uri);
+	
+	directory = nautilus_directory_get (location);
 	
 	g_assert (NAUTILUS_IS_SEARCH_DIRECTORY (directory));
 
@@ -1036,7 +1090,7 @@ search_bar_activate_callback (NautilusSearchBar *bar,
 	query = nautilus_search_bar_get_query (NAUTILUS_SEARCH_BAR (NAUTILUS_NAVIGATION_WINDOW (window)->search_bar));
 	if (query != NULL) {
 		if (!nautilus_search_directory_is_indexed (search_directory)) {
-			current_uri = nautilus_window_get_location (window);
+			current_uri = nautilus_window_get_location_uri (window);
 			nautilus_query_set_location (query, current_uri);
 			g_free (current_uri);
 		}
@@ -1044,10 +1098,10 @@ search_bar_activate_callback (NautilusSearchBar *bar,
 		g_object_unref (query);
 	}
 	
-	nautilus_window_go_to (window, uri);
+	nautilus_window_go_to (window, location);
 	
 	nautilus_directory_unref (directory);
-	g_free (uri);
+	g_object_unref (location);
 }
 
 static void
@@ -1535,13 +1589,16 @@ nautilus_navigation_window_class_init (NautilusNavigationWindowClass *class)
 	GTK_WIDGET_CLASS (class)->show = nautilus_navigation_window_show;
 	GTK_WIDGET_CLASS (class)->unrealize = nautilus_navigation_window_unrealize;
 	GTK_WIDGET_CLASS (class)->window_state_event = nautilus_navigation_window_state_event;
+	GTK_WIDGET_CLASS (class)->key_press_event = nautilus_navigation_window_key_press_event;
 	NAUTILUS_WINDOW_CLASS (class)->load_view_as_menu = real_load_view_as_menu;
 	NAUTILUS_WINDOW_CLASS (class)->set_content_view_widget = real_set_content_view_widget;
 	NAUTILUS_WINDOW_CLASS (class)->set_throbber_active = real_set_throbber_active;
 	NAUTILUS_WINDOW_CLASS (class)->prompt_for_location = real_prompt_for_location;
 	NAUTILUS_WINDOW_CLASS (class)->set_search_mode = real_set_search_mode;
 	NAUTILUS_WINDOW_CLASS (class)->set_title = real_set_title;
-	NAUTILUS_WINDOW_CLASS (class)->get_icon_name = real_get_icon_name;
+	NAUTILUS_WINDOW_CLASS (class)->get_icon = real_get_icon;
 	NAUTILUS_WINDOW_CLASS (class)->get_default_size = real_get_default_size;
 	NAUTILUS_WINDOW_CLASS (class)->close = real_window_close;
+
+	g_type_class_add_private (G_OBJECT_CLASS (class), sizeof (NautilusNavigationWindowDetails));
 }
