@@ -625,16 +625,6 @@ nautilus_window_open_location_with_selection (NautilusWindow *window,
 					    flags, selection);
 }					      
 
-char *
-nautilus_window_get_view_label (NautilusWindow *window)
-{
-	const NautilusViewInfo *info;
-
-	info = nautilus_view_factory_lookup (nautilus_window_get_content_view_id (window));
-
-	return g_strdup (info->label);
-}
-
 char *
 nautilus_window_get_view_error_label (NautilusWindow *window)
 {
@@ -923,6 +913,7 @@ mount_not_mounted_callback (GObject *source_object,
 		window->details->mount_error = NULL;
 		g_error_free (error);
 	} else {
+		nautilus_inhibit_autorun_for_file (G_FILE (source_object));
 		nautilus_file_invalidate_all_attributes (window->details->determine_view_file);
 		nautilus_file_call_when_ready (window->details->determine_view_file,
 					       NAUTILUS_FILE_ATTRIBUTE_INFO |
@@ -1688,13 +1679,13 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 	if (error == NULL) {
 		if (nautilus_file_is_directory (file)) {
 			error_message = g_strdup_printf
-				(_("Couldn't display \"%s\"."),
+				(_("Could not display \"%s\"."),
 				 uri_for_display);
 			detail_message = g_strdup 
 				(_("Nautilus has no installed viewer capable of displaying the folder."));
 		} else {
 			error_message = g_strdup_printf
-				(_("Couldn't display \"%s\"."),
+				(_("Could not display \"%s\"."),
 				 uri_for_display);
 			detail_message = g_strdup 
 				(_("The location is not a folder."));
@@ -1703,7 +1694,7 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 		switch (error->code) {
 		case G_IO_ERROR_NOT_FOUND:
 			error_message = g_strdup_printf
-				(_("Couldn't find \"%s\"."), 
+				(_("Could not find \"%s\"."), 
 				 uri_for_display);
 			detail_message = g_strdup 
 				(_("Please check the spelling and try again."));
@@ -1711,7 +1702,7 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 		case G_IO_ERROR_NOT_SUPPORTED:
 			scheme_string = g_file_get_uri_scheme (location);
 				
-			error_message = g_strdup_printf (_("Couldn't display \"%s\"."),
+			error_message = g_strdup_printf (_("Could not display \"%s\"."),
 							 uri_for_display);
 			if (scheme_string != NULL) {
 				detail_message = g_strdup_printf (_("Nautilus cannot handle %s: locations."),
@@ -1722,13 +1713,13 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 			g_free (scheme_string);
 			break;
 		case G_IO_ERROR_NOT_MOUNTED:
-			error_message = g_strdup_printf (_("Couldn't display \"%s\"."),
+			error_message = g_strdup_printf (_("Could not display \"%s\"."),
 							 uri_for_display);
 			detail_message = g_strdup (_("Unable to mount the location."));
 			break;
 			
 		case G_IO_ERROR_PERMISSION_DENIED:
-			error_message = g_strdup_printf (_("Couldn't display \"%s\"."),
+			error_message = g_strdup_printf (_("Could not display \"%s\"."),
 							 uri_for_display);
 			detail_message = g_strdup (_("Access was denied."));
 			break;
@@ -1739,7 +1730,7 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 			 * But this case is also hit for legitimate web addresses when
 			 * the proxy is set up wrong.
 			 */
-			error_message = g_strdup_printf (_("Couldn't display \"%s\", because the host could be found."),
+			error_message = g_strdup_printf (_("Could not display \"%s\", because the host could not be found."),
 							 uri_for_display);
 			detail_message = g_strdup (_("Check that the spelling is correct and that your proxy settings are correct."));
 			break;
@@ -1753,7 +1744,7 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 	}
 	
 	if (error_message == NULL) {
-		error_message = g_strdup_printf (_("Couldn't display \"%s\"."),
+		error_message = g_strdup_printf (_("Could not display \"%s\"."),
 						 uri_for_display);
 		detail_message = g_strdup_printf (_("Error: %s\nPlease select another viewer and try again."), error->message);
 	}
