@@ -205,16 +205,27 @@ nautilus_window_ui_update (NautilusWindow *window)
 	gtk_ui_manager_ensure_update (window->details->ui_manager);
 }
 
+static gboolean
+nautilus_window_clear_status (gpointer callback_data)
+{
+	NautilusWindow *window;
+
+	window = NAUTILUS_WINDOW (callback_data);
+
+	gtk_statusbar_pop (GTK_STATUSBAR (window->details->statusbar), 0); /* clear any previous message, underflow is allowed */
+
+	return FALSE;
+}
+
 void
 nautilus_window_set_status (NautilusWindow *window, const char *text)
 {
 	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 
-	/* clear any previous message, underflow is allowed */
-	gtk_statusbar_pop (GTK_STATUSBAR (window->details->statusbar), 0);
-
 	if (text != NULL && text[0] != '\0') {
 		gtk_statusbar_push (GTK_STATUSBAR (window->details->statusbar), 0, text);
+	} else {
+		nautilus_window_clear_status (window);
 	}
 }
 
@@ -814,7 +825,7 @@ add_view_as_menu_item (NautilusWindow *window,
 	
 	g_snprintf (action_name, sizeof (action_name), "view_as_%d", index);
 	action = gtk_radio_action_new (action_name,
-				       _(info->view_as_label_with_mnemonic),
+				       _(info->view_menu_label_with_mnemonic),
 				       _(info->display_location_label),
 				       NULL,
 				       0);
